@@ -95,7 +95,6 @@ siena08 <- function(..., projname="sienaMeta", bound=5, alpha=0.05, maxit=20)
                     )
     ## make sure the effects are in the right order.
     mydf$effects <- factor(mydf$effects, levels=unique(mydf$effects))
-    ##count the score tests
 
     ## produce meta analysis object
     dometa <- function(x)
@@ -181,13 +180,32 @@ siena08 <- function(..., projname="sienaMeta", bound=5, alpha=0.05, maxit=20)
     }
 
     meta <- by(mydf, mydf$effects, dometa)
+# copy effect specification and ML estimates
+# to components requestedEffects, theta and se
+	requestedEffects <- ex[[1]]$requestedEffects
+	if (dim(requestedEffects)[1] != length(unique(mydf$effects))){
+		cat('\nWarning: length requestedEffects incorrect.\n')
+		print(requestedEffects)
+		print(mydf$effects)
+	}
+	meta.theta <- sapply(meta,
+					function(x){ifelse(is.null(x$mu.ml),NA,x$mu.ml)})
+	meta.theta[is.na(meta.theta)] <- 0
+	meta.se <- sapply(meta,
+					function(x){ifelse(is.null(x$mu.ml.se),NA,x$mu.ml.se)})
+	names(meta.theta) <- rep('', length(meta.theta))
+	names(meta.se) <- rep('', length(meta.se))
+# add everything to the meta object created
     meta$thetadf <- mydf
     class(meta) <- "sienaMeta"
     meta$projname <- projname
     meta$bound <- bound
     ## count the score tests
-    meta$scores <- by(mydf, mydf$effects, function(x)
-                      any(!is.na(x$scoretests)))
+    meta$scores <- by(mydf, mydf$effects,
+					function(x){any(!is.na(x$scoretests))})
+	meta$requestedEffects <- requestedEffects
+	meta$theta <- meta.theta
+	meta$se <- meta.se
     meta
 }
 
@@ -418,282 +436,308 @@ summary.sienaMeta <- function(object, file=FALSE, extra=TRUE, ...)
 ##@print.summary.sienaMeta Methods
 print.summary.sienaMeta <- function(x, file=FALSE, extra=TRUE, ...)
 {
-    exitfn <- function()
-    {
-        if (file)
-        {
-            ## close the report file
-            Report(closefiles=TRUE)
-        }
+	exitfn <- function()
+	{
+		if (file)
+		{
+			## close the report file
+			Report(closefiles=TRUE)
+		}
 
-    }
-    on.exit(exitfn())
-    if (!is.null(x$file))
-    {
-        file <- x$file
-    }
-    if (!is.null(x$extra))
-    {
-        extra <- x$extra
-    }
-    projname <- x$projname
-    if (file)
-    {
-        Report(openfiles=TRUE, type="a", projname=projname) # initialise a file
-    }
-    else
-    {
-        Report(openfiles=TRUE, type="n") #initialise with no file
-    }
-    if (file)
-    {
-        ## do some sums for the heading
+	}
+	on.exit(exitfn())
+	if (!is.null(x$file))
+	{
+		file <- x$file
+	}
+	if (!is.null(x$extra))
+	{
+		extra <- x$extra
+	}
+	projname <- x$projname
+	if (file)
+	{
+		Report(openfiles=TRUE, type="a", projname=projname) # initialise a file
+	}
+	else
+	{
+		Report(openfiles=TRUE, type="n") #initialise with no file
+	}
+	if (file)
+	{
+		## do some sums for the heading
 
-        namelen <- nchar(projname) + 4
-        ##linelen <- 80
-        astlen <- min(namelen + 10, 80)
-        nBlanks <- if (astlen < 80)
-        {
-            (80 - astlen) %/% 2
-        }
-        else
-        {
-            0
-        }
-        nBlanks2 <- if (namelen < 80)
-        {
-            (80 - namelen) %/% 2
-        }
-        else
-        {
-            0
-        }
-        Report(c(rep(" ", nBlanks), rep("*", astlen), "\n"), sep="", outf)
-        Report(c(rep(" ", nBlanks2), projname, ".out\n"), sep="", outf)
-        Report(c(rep(" ", nBlanks), rep("*", astlen), "\n"), sep="", outf)
-        Report(c("Filename is ", projname, ".out.\n\n"), sep="", outf)
-        Report(c("This file contains primary output for SIENA project <<",
-                 projname, ">>.\n\n"), sep="", outf)
-        Report(c("Date and time:", format(Sys.time(),
-                                          "%d/%m/%Y %X"), "\n\n"), outf)
-        packageValues <- packageDescription(pkgname,
-                                            fields=c("Version", "Date"))
-        rforgeRevision <-  packageDescription(pkgname,
-                                              fields=
-                                              "Repository/R-Forge/Revision")
-        if (is.na(rforgeRevision))
-        {
-            revision <- ""
-        }
-        else
-        {
-            revision <- paste(" R-forge revision: ", rforgeRevision,
-                              " ", sep="")
-        }
-        Report(c("RSiena version ", packageValues[[1]], " (",
-                 format(as.Date(packageValues[[2]]), "%d %m %Y"), ")",
-                 revision, "\n\n"), sep="", outf)
-    }
-    Report(c("================================= SIENA08 ",
-             "================================================\n",
-             "Multilevel use of Siena algorithms according to ",
-             "Snijders & Baerveldt (2003) with extension\n",
-             "=================================================",
-             "=========================================\n\n"), sep="", outf)
-    projnames <- unique(x$thetadf$projname)
-    nProjects <- length(projnames)
-    effects <- unique(x$thetadf$effects)
-    nEffects <- length(effects)
-    Report(c("Number of projects in the list is " ,
-             length(projnames), ".\n"), sep="", outf)
-    Report("The names of these projects are :\n", outf)
-    tmp <- paste("project", 1:nProjects, ": <", projnames,
-                 ">\n", sep="")
-    Report(tmp, sep="", outf)
-    Report(c("\nOptions for running Siena08:\n",
-             "-> Parameters are excluded from the meta-analysis when their ",
-             "standard\n", "   error exceeds an upper bound of ",
-             round(x$bound,digits=2), ".\n"), sep="", outf)
-    if (extra)
-    {
-        Report("-> Extra output requested\n", outf)
-    }
-    else
-    {
-        Report("-> No extra output requested\n", outf)
-    }
-    ## RSiena version
-    Report(c("\nThe RSiena Version of the first fit object is ",
-             x$thetadf$version[1], ".\n\n"), sep="", outf)
-    ## project names
-    by(x$thetadf, x$thetadf$projname, function(x)
-   {
-       Report(c("Object <", x$projname[1], "> contains estimates of ",
-                nrow(x), " parameters.\n"), sep="", outf)
-       Report(c("The number of valid score tests found was ",
-                sum(is.na(x$scoretests)), ".\n"),
-              sep="", outf);
-   })
-    ##parameters:
-    Report(c("\nA total of", nEffects, "parameters in", nProjects,
-             "projects :\n"),   outf)
-    Report(paste(format(1:length(effects)), ". " , effects, "\n", sep=""),
-           sep="", outf)
-    Report(c("\nThe projects contain the parameters as follows",
-             "(1=present, 0=absent):\n\n"), outf)
-    row1 <- c(1:nEffects)
-    rows <- do.call(rbind, tapply(x$thetadf$effects,
-                                  x$thetadf$projname, function(x)
-                              {
-                                  as.numeric(effects %in% x)
-                              }
-                                  )
-                    )
-    rows <- format(rbind(row1, rows), width=3)
-    row2 <- rep(paste(rep("-", nchar(rows[1, 1])), collapse=""), nEffects)
-    rows <- rbind(rows[1,], row2, rows[-1, ])
-    col1 <- format(rbind("Project",
-                         paste(rep("-", 7), collapse=""),
-                         cbind(1:nProjects)), justify="centre")
-    col2 <- format(rbind( "|",  "--+--",  cbind(rep("|", nProjects))),
-                   justify="centre")
-    rows <- cbind(col1, col2, rows)
-    Report(t(rows), sep = c(rep.int("", ncol(rows) - 1), "\n"), outf)
-    by(x$thetadf, x$thetadf$projname, function(x)
-   {
-       Report(c("\nProject", x$projname[1], "\n"), outf)
-       tmp <- paste("par.", 1:nEffects, "estimate",
-                    format(round(x$theta, 4), width=12), "(s.e. ",
-                    format(round(x$se, 4), width=11), ") (conv_t",
-                    format(round(x$tconv, 4), width=9), ")\n")
-       Report(format(tmp), sep="", outf)
-       Report(c("\nMaximal absolute convergence t-statistic = ",
-                format(round(max(abs(x$tconv)), 4), width=9), "\n"), outf)
-       ## score tests
-   })
-    ## results
+		namelen <- nchar(projname) + 4
+		##linelen <- 80
+		astlen <- min(namelen + 10, 80)
+		nBlanks <- if (astlen < 80)
+		{
+			(80 - astlen) %/% 2
+		}
+			else
+			{
+				0
+			}
+		nBlanks2 <- if (namelen < 80)
+		{
+			(80 - namelen) %/% 2
+		}
+			else
+			{
+				0
+			}
+		Report(c(rep(" ", nBlanks), rep("*", astlen), "\n"), sep="", outf)
+		Report(c(rep(" ", nBlanks2), projname, ".out\n"), sep="", outf)
+		Report(c(rep(" ", nBlanks), rep("*", astlen), "\n"), sep="", outf)
+		Report(c("Filename is ", projname, ".out.\n\n"), sep="", outf)
+		Report(c("This file contains primary output for SIENA project <<",
+				projname, ">>.\n\n"), sep="", outf)
+		Report(c("Date and time:", format(Sys.time(),
+					"%d/%m/%Y %X"), "\n\n"), outf)
+		packageValues <- packageDescription(pkgname,
+			fields=c("Version", "Date"))
+		rforgeRevision <-  packageDescription(pkgname,
+			fields=
+				"Repository/R-Forge/Revision")
+		if (is.na(rforgeRevision))
+		{
+			revision <- ""
+		}
+		else
+		{
+			revision <- paste(" R-forge revision: ", rforgeRevision,
+				" ", sep="")
+		}
+		Report(c(paste(pkgname, "version "), packageValues[[1]], " (",
+				format(as.Date(packageValues[[2]]), "%d %m %Y"), ")",
+				revision, "\n\n"), sep="", outf)
+	}
+	Report(c("================================= SIENA08 ",
+			"================================================\n",
+			"Multilevel use of Siena algorithms according to ",
+			"Snijders & Baerveldt (2003) with extension\n",
+			"=================================================",
+			"=========================================\n\n"), sep="", outf)
+	projnames <- unique(x$thetadf$projname)
+	nProjects <- length(projnames)
+	effects <- unique(x$thetadf$effects)
+	nEffects <- length(effects)
+	Report(c("Number of projects in the list is " ,
+			length(projnames), ".\n"), sep="", outf)
+	Report("The names of these projects are :\n", outf)
+	tmp <- paste("project", 1:nProjects, ": <", projnames,
+		">\n", sep="")
+	Report(tmp, sep="", outf)
+	Report(c("\nOptions for running Siena08:\n",
+			"-> Parameters are excluded from the meta-analysis when their ",
+			"standard\n", "   error exceeds an upper bound of ",
+			round(x$bound,digits=2), ".\n"), sep="", outf)
+	if (extra)
+	{
+		Report("-> Extra output requested\n", outf)
+	}
+	else
+	{
+		Report("-> No extra output requested\n", outf)
+	}
+	## RSiena version
+	Report(c("\nThe RSiena Version of the first fit object is ",
+			x$thetadf$version[1], ".\n\n"), sep="", outf)
+	## project names
+	by(x$thetadf, x$thetadf$projname, function(x)
+		{
+			Report(c("Object <", x$projname[1], "> contains estimates of ",
+					nrow(x), " parameters.\n"), sep="", outf)
+			Report(c("The number of valid score tests found was ",
+					sum(is.na(x$scoretests)), ".\n"),
+				sep="", outf);
+		})
+	##parameters:
+	Report(c("\nA total of", nEffects, "parameters in", nProjects,
+			"projects :\n"),   outf)
+	Report(paste(format(1:length(effects)), ". " , effects, "\n", sep=""),
+		sep="", outf)
+	Report(c("\nThe projects contain the parameters as follows",
+			"(1=present, 0=absent):\n\n"), outf)
+	row1 <- c(1:nEffects)
+	rows <- do.call(rbind, tapply(x$thetadf$effects,
+			x$thetadf$projname, function(x)
+			{
+				as.numeric(effects %in% x)
+			}
+			)
+		)
+	rows <- format(rbind(row1, rows), width=3)
+	row2 <- rep(paste(rep("-", nchar(rows[1, 1])), collapse=""), nEffects)
+	rows <- rbind(rows[1,], row2, rows[-1, ])
+	col1 <- format(rbind("Project",
+			paste(rep("-", 7), collapse=""),
+			cbind(1:nProjects)), justify="centre")
+	col2 <- format(rbind( "|",  "--+--",  cbind(rep("|", nProjects))),
+		justify="centre")
+	rows <- cbind(col1, col2, rows)
+	Report(t(rows), sep = c(rep.int("", ncol(rows) - 1), "\n"), outf)
+	by(x$thetadf, x$thetadf$projname, function(x)
+		{
+			Report(c("\nProject", x$projname[1], "\n"), outf)
+			tmp <- paste("par.", 1:nEffects, "estimate",
+				format(round(x$theta, 4), width=12), "(s.e. ",
+				format(round(x$se, 4), width=11), ") (conv_t",
+				format(round(x$tconv, 4), width=9), ")\n")
+			Report(format(tmp), sep="", outf)
+			Report(c("\nMaximal absolute convergence t-statistic = ",
+					format(round(max(abs(x$tconv)), 4), width=9), "\n"), outf)
+			## score tests
+		})
+	## results
 
-    ## estimates
-    Report(c("\n\n", paste(rep("=", 29), collapse=""),
-             "\nResults of the meta-analysis:\n",
-             paste(rep("=", 29), collapse=""), "\n"), sep="", outf)
+	## estimates
+	Report(c("\n\n", paste(rep("=", 29), collapse=""),
+			"\nResults of the meta-analysis:\n",
+			paste(rep("=", 29), collapse=""), "\n"), sep="", outf)
 
-    Report(c("\nUpper bound used for standard error is",
-             format(round(x$bound, 4), width=9, nsmall=2), ".\n"), sep="", outf)
+	Report(c("\nUpper bound used for standard error is",
+			format(round(x$bound, 4), width=9, nsmall=2), ".\n"), sep="", outf)
 
-    dashes <- paste(rep("-", 80), collapse="")
-    x$thetadf$excl <- ifelse(x$thetadf$se > x$bound,
-                             " EXCLUDED from meta-analysis", "")
-    by(x$thetadf, x$thetadf$effects, function(x, y)
-   {
-       i <- match(x$effects[1], effects)
-       y <- y[[effects[i]]]
-       Report(c("\n", dashes, "\nParameter ", i, ": ",
-                as.character(x$effects[1]), "\n", dashes, "\n"),
-              sep="", outf)
-       tmp <- paste("Data set ", 1:nrow(x), ", ", format(x$projname),
-                    " :  Estimate ",
-                    format(round(x$theta, 4), width=12),
-                    " (standard error ",
-                    format(round(x$se, 2), nsmall=2,
-                           width=11), ")", x$excl, "\n", sep="")
-       Report(c(tmp, "\n"), sep="", outf)
-       Report(c(" ", y$n1, " datasets used.\n\n"), sep="", outf)
-       if (y$n1 > 0)
-       {
-           if (extra)
-           {
-               Report(c("IWLS modification of Snijders-Baerveldt (2003) method ",
-                        "of combining estimates"), outf)
-               Report(c("\n--------------------------------------------",
-                        "---------------------------------\n"), sep="", outf)
-               Report(c("This method assumes that true parameters and",
-                        " standard errors are uncorrelated.\n",
-                        "This can be checked by the plot method ",
-                        "and the test below.\n\n"), sep="", outf)
-           }
-           Report("Test that estimates and standard errors are uncorrelated",
-                  outf)
-           if (is.na(y$cor.est))
-           {
-               Report("\ncannot be performed.\n\n", outf)
-           }
-           else
-           {
-               Report(c(": \n", y$cor.meth, " =", format(round(y$cor.est, 4),
-                                                            width=9),
-                        ", two-sided ",reportp(y$cor.pval,3), "\n\n"),
-                      sep="", outf)
-           }
-           Report(c("Test that all parameters are 0 : \n"), outf)
-           Report(c("chi-squared =", format(round(y$Tsq, 4), width=9),
-                    ", d.f. = ", y$n1, ", ",
-                    reportp(y$pTsq, 3), "\n\n"), sep="", outf)
-           Report(c("Estimated mean parameter",
-                    format(round(y$regsummary$coefficients[1, 1], 4), width=9),
-                    " (s.e.", format(round(y$regsummary$coefficients[1, 2], 4),
-                                     width=9), "), two-sided ",
-                    reportp(pt(y$regsummary$coefficients[1, 3],
-                               y$n1 - 1), 3), "\n"), sep="", outf)
-           Report(c("based on IWLS modification of Snijders & Baerveldt (2003). ",
-                  "\n\n"), sep="", outf)
-           Report(c("Residual standard error",
-                    format(round(y$regsummary$stddev, 4), width=9)), outf)
-           Report("\nTest that variance of parameter is 0 :\n",outf)
-           Report(c("Chi-squared = ", format(round(y$Qstat, 4), width=9),
-	            " (d.f. = ", y$n1-1, "), ", reportp(y$pttilde, 3),
-	            "\n"), sep="", outf)
-           Report(c("based on IWLS modification of Snijders & Baerveldt (2003).",
-                  "\n\n"), sep="", outf)
-           Report("Fisher's combination of one-sided tests\n", outf)
-           Report("----------------------------------------\n", outf)
-           Report("Combination of right one-sided p-values:\n", outf)
-           Report(c("Chi-squared = ", format(round(y$cjplus, 4), width=9),
-                    " (d.f. = ", 2 * y$n1, "), ", reportp(y$cjplusp, 3),
-                    "\n"), sep="", outf)
-           Report("Combination of left one-sided p-values:\n", outf)
-           Report(c("Chi-squared = ", format(round(y$cjminus, 4), width=9),
-                    " (d.f. = ", 2 * y$n1, "), ", reportp(y$cjminusp, 3),
-                    "\n"), sep="", outf)
-       }
-       else
-       {
-           Report(c("There were no data sets satisfying the bounds for",
-                    "this parameter.\n No combined output is given.\n"), outf)
-       }
-   }, y=x)
-    ##score tests
-    if (any(x$scores))
-    {
-        Report(c("\n\n", paste(rep("-", 65), collapse=""),
-                 "\nScore tests:\nFisher combination\n",
-                 paste(rep("-", 65), collapse=""), "\n"), sep="", outf)
-
-        invisible(by(x$thetadf, x$thetadf$effects, function(x, y)
-       {
-           i <- match(x$effects[1], effects)
-           y <- y[[effects[i]]]
-           if (y$ns > 0)
-           {
-               Report(c("\n", "(", i, ")   ",
-                        as.character(x$effects[1]), "\n"), sep="", outf)
-               tmp <- paste("Data set ", 1:nrow(x), ", ", format(x$projname),
-                            " : z = ",
-                            ifelse(is.na(x$scoretests), "NA",
-                                   format(round(x$scoretests, 4), width=12)),
-                            "\n", sep="")
-               Report(c(tmp, "\n"), sep="", outf)
-               Report("Combination of right one-sided p-values:\n", outf)
-               Report(c("Chi-squared = ", format(round(y$scoreplus, 4),
-                                                 width=9),
-                        " (d.f. = ", 2 * y$ns, "), ",
-                        reportp(y$scoreplusp, 3), "\n"), sep="", outf)
-        Report("Bonferroni combination of left and right one-sided p-values:\n",
-						outf)
-               Report(c(reportp(2*min(y$scoreminusp, y$scoreplusp), 3), "\n"),
+	dashes <- paste(rep("-", 80), collapse="")
+	x$thetadf$excl <- ifelse(x$thetadf$se > x$bound,
+		" EXCLUDED from meta-analysis", "")
+	by(x$thetadf, x$thetadf$effects, function(x, y)
+		{
+			i <- match(x$effects[1], effects)
+			y <- y[[effects[i]]]
+			Report(c("\n", dashes, "\nParameter ", i, ": ",
+					as.character(x$effects[1]), "\n", dashes, "\n"),
+				sep="", outf)
+			tmp <- paste("Data set ", 1:nrow(x), ", ", format(x$projname),
+				" :  Estimate ",
+				format(round(x$theta, 4), width=12),
+				" (standard error ",
+				format(round(x$se, 2), nsmall=2,
+					width=11), ")", x$excl, "\n", sep="")
+			Report(c(tmp, "\n"), sep="", outf)
+			Report(c(" ", y$n1, " datasets used.\n\n"), sep="", outf)
+			if (y$n1 > 0)
+			{
+				if (extra)
+				{
+					Report(c("IWLS modification of Snijders-Baerveldt (2003) method ",
+							"of combining estimates"), outf)
+					Report(c("\n--------------------------------------------",
+							"---------------------------------\n"), sep="", outf)
+					Report(c("This method assumes that true parameters and",
+							" standard errors are uncorrelated.\n",
+							"This can be checked by the plot method ",
+							"and the test below.\n\n"), sep="", outf)
+				}
+				Report("Test that estimates and standard errors are uncorrelated",
+					outf)
+				if (is.na(y$cor.est))
+				{
+					Report("\ncannot be performed.\n\n", outf)
+				}
+				else
+				{
+					Report(c(": \n", y$cor.meth, " =", format(round(y$cor.est, 4),
+								width=9),
+							", two-sided ",reportp(y$cor.pval,3), "\n\n"),
 						sep="", outf)
-           }
-       }, y=x))
-    }
+				}
+				Report(c("Test that all parameters are 0 : \n"), outf)
+				Report(c("chi-squared =", format(round(y$Tsq, 4), width=9),
+						", d.f. = ", y$n1, ", ",
+						reportp(y$pTsq, 3), "\n\n"), sep="", outf)
+				Report(c("Estimated mean parameter",
+						format(round(y$regsummary$coefficients[1, 1], 4), width=9),
+						" (s.e.", format(round(y$regsummary$coefficients[1, 2], 4),
+							width=9), "), two-sided ",
+						reportp(2*pt(-abs(y$regsummary$coefficients[1, 3]),
+								y$n1 - 1), 3), "\n"), sep="", outf)
+				Report(c("based on IWLS modification of Snijders & Baerveldt (2003). ",
+						"\n\n"), sep="", outf)
+				Report(c("Residual standard error",
+						format(round(y$regsummary$stddev, 4), width=9)), outf)
+				Report("\nTest that variance of parameter is 0 :\n",outf)
+				Report(c("Chi-squared = ", format(round(y$Qstat, 4), width=9),
+						" (d.f. = ", y$n1-1, "), ", reportp(y$pttilde, 3),
+						"\n"), sep="", outf)
+				Report(c("based on IWLS modification of Snijders & Baerveldt (2003).",
+						"\n\n"), sep="", outf)
+
+				Report(c("Estimates and confidence intervals under normality",
+                    "assumptions\n"), outf)
+				Report(c("-------------------------------------------------------",
+                    "-------\n"), outf)
+				Report(c("Estimated mean parameter",
+                    format(round(y$mu.ml, 4), width=9),
+                    " (s.e.",format(round(y$mu.ml.se, 4), width=9),
+                    "), two-sided ",
+                    reportp(2 * pt(-abs(y$mu.ml/y$mu.ml.se),
+                                   y$n1 - 1), 3), "\n"), sep="", outf)
+				Report(c(format(round(y$mu.confint[3], 2), width=4),
+                    "level confidence interval [",
+                    format(round(y$mu.confint[1], 4), width=7),
+                    ",",
+                    format(round(y$mu.confint[2], 4), width=7), "]\n"), outf)
+				Report(c("Estimated standard deviation",
+                    ifelse((y$sigma.ml > 0.0001) | (y$sigma.ml < 0.0000001),
+                           format(round(y$sigma.ml, 4), width=9), " < 0.0001"),
+                     "\n"), outf)
+				Report(c(format(round(y$sigma.confint[3], 2), width=4),
+                    "level confidence interval [",
+                    format(round(y$sigma.confint[1], 4), width=7),
+                    ",",
+                    format(round(y$sigma.confint[2], 4), width=7), "]\n\n"), outf)
+
+				Report("Fisher's combination of one-sided tests\n", outf)
+				Report("----------------------------------------\n", outf)
+				Report("Combination of right one-sided p-values:\n", outf)
+				Report(c("Chi-squared = ", format(round(y$cjplus, 4), width=9),
+						" (d.f. = ", 2 * y$n1, "), ", reportp(y$cjplusp, 3),
+						"\n"), sep="", outf)
+				Report("Combination of left one-sided p-values:\n", outf)
+				Report(c("Chi-squared = ", format(round(y$cjminus, 4), width=9),
+						" (d.f. = ", 2 * y$n1, "), ", reportp(y$cjminusp, 3),
+						"\n"), sep="", outf)
+			}
+			else
+			{
+				Report(c("There were no data sets satisfying the bounds for",
+						"this parameter.\n No combined output is given.\n"), outf)
+			}
+		}, y=x)
+	##score tests
+	if (any(x$scores))
+	{
+		Report(c("\n\n", paste(rep("-", 65), collapse=""),
+				"\nScore tests:\nFisher combination\n",
+				paste(rep("-", 65), collapse=""), "\n"), sep="", outf)
+
+		invisible(by(x$thetadf, x$thetadf$effects, function(x, y)
+				{
+					i <- match(x$effects[1], effects)
+					y <- y[[effects[i]]]
+					if (y$ns > 0)
+					{
+						Report(c("\n", "(", i, ")   ",
+								as.character(x$effects[1]), "\n"), sep="", outf)
+						tmp <- paste("Data set ", 1:nrow(x), ", ", format(x$projname),
+							" : z = ",
+							ifelse(is.na(x$scoretests), "NA",
+								format(round(x$scoretests, 4), width=12)),
+							"\n", sep="")
+						Report(c(tmp, "\n"), sep="", outf)
+						Report("Combination of right one-sided p-values:\n", outf)
+						Report(c("Chi-squared = ", format(round(y$scoreplus, 4),
+									width=9),
+								" (d.f. = ", 2 * y$ns, "), ",
+								reportp(y$scoreplusp, 3), "\n"), sep="", outf)
+						Report("Bonferroni combination of left and right one-sided p-values:\n",
+							outf)
+						Report(c(reportp(2*min(y$scoreminusp, y$scoreplusp), 3), "\n"),
+							sep="", outf)
+					}
+				}, y=x))
+	}
 }
 
