@@ -17,6 +17,8 @@
 #include "network/IncidentTieIterator.h"
 #include "data/ActorSet.h"
 
+using namespace std;
+
 namespace siena
 {
 
@@ -49,6 +51,8 @@ NetworkLongitudinalData::NetworkLongitudinalData(int id,
 	this->lnetworksLessMissings = new Network * [observationCount];
 	this->lnetworksLessMissingStarts = new Network * [observationCount];
 	this->lmaxDegree = std::numeric_limits<int>::max();
+	this->lmodelType = 1;
+	this->luniversalOffset = numeric_limits<double>::max();
 	this->ldensity = new double[observationCount];
 	this->loneMode = oneMode;
 
@@ -119,6 +123,8 @@ void NetworkLongitudinalData::calculateProperties()
 
 	this->laverageInDegree = 0;
 	this->laverageOutDegree = 0;
+	this->laverageSquaredInDegree = 0;
+	this->laverageSquaredOutDegree = 0;
 
 	for (int observation = 0;
 		observation < this->observationCount();
@@ -130,6 +136,8 @@ void NetworkLongitudinalData::calculateProperties()
 		for (int i = 0; i < this->lpReceivers->n(); i++)
 		{
 			this->laverageInDegree += pNetwork->inDegree(i);
+			this->laverageSquaredInDegree +=
+					(pNetwork->inDegree(i))*(pNetwork->inDegree(i));
 		}
 
 		int observedTieCount = 0;
@@ -137,6 +145,8 @@ void NetworkLongitudinalData::calculateProperties()
 		for (int i = 0; i < this->pActorSet()->n(); i++)
 		{
 			this->laverageOutDegree += pNetwork->outDegree(i);
+			this->laverageSquaredOutDegree +=
+				(pNetwork->outDegree(i))*(pNetwork->outDegree(i));
 			observedTieCount +=
 				pNetwork->outDegree(i) -
 					commonActorCount(pNetwork->outTies(i),
@@ -170,6 +180,10 @@ void NetworkLongitudinalData::calculateProperties()
 		this->lpReceivers->n() * this->observationCount();
 	this->laverageOutDegree /=
 		this->pActorSet()->n() * this->observationCount();
+	this->laverageSquaredInDegree /=
+		this->lpReceivers->n() * this->observationCount();
+	this->laverageSquaredOutDegree /=
+		this->pActorSet()->n() * this->observationCount();
 
 	// data-less-missing-values is used in calculating statistics. Since it
 	// does not change we store it, hoping we have enough space!
@@ -354,6 +368,20 @@ int NetworkLongitudinalData::structuralTieCount(int actor, int observation)
 	return this->lstructuralTieNetworks[observation]->outDegree(actor);
 }
 
+/**
+ * Returns the number of receivers.
+ */
+int NetworkLongitudinalData::m() const
+{
+		if (this->loneMode )
+		{
+			return pActorSet()->n();
+		}
+		else
+		{
+			return this->lpReceivers->n();
+		}
+}
 
 /**
  * Stores the maximum permitted out-degree of an actor.
@@ -363,6 +391,21 @@ void NetworkLongitudinalData::maxDegree(int degree)
 	this->lmaxDegree = degree;
 }
 
+/**
+ * Stores the offset for the universal setting.
+ */
+void NetworkLongitudinalData::universalOffset(double offset) {
+	this->luniversalOffset = offset;
+}
+
+
+/**
+ * Stores the model type.
+ */
+void NetworkLongitudinalData::modelType(int type)
+{
+	this->lmodelType = type;
+}
 
 /**
  * Returns the maximum permitted out-degree of an actor.
@@ -371,6 +414,23 @@ int NetworkLongitudinalData::maxDegree() const
 {
 	return this->lmaxDegree;
 }
+
+/**
+ * Returns the offset for the universal setting.
+ */
+double NetworkLongitudinalData::universalOffset() const {
+	return this->luniversalOffset;
+}
+
+/**
+ * Returns the model type.
+ */
+int NetworkLongitudinalData::modelType() const
+{
+	return this->lmodelType;
+}
+
+
 /**
  * Stores the average in-degree over all receivers and observations.
  */
@@ -397,6 +457,14 @@ double NetworkLongitudinalData::averageInDegree() const
 	return this->laverageInDegree;
 }
 
+/**
+ * Returns the average squared in-degree over all receivers and observations.
+ */
+double NetworkLongitudinalData::averageSquaredInDegree() const
+{
+	return this->laverageSquaredInDegree;
+}
+
 
 /**
  * Returns the average out-degree over all senders and observations.
@@ -406,6 +474,14 @@ double NetworkLongitudinalData::averageOutDegree() const
 	return this->laverageOutDegree;
 }
 
+/**
+ * Returns the average squared out-degree over all senders and observations.
+ */
+double NetworkLongitudinalData::averageSquaredOutDegree() const
+{
+	return this->laverageSquaredOutDegree;
+}
+
 
 /**
  * Returns the relative frequency of the given value among the
