@@ -28,6 +28,8 @@ public:
 
 	virtual double calculateChangeContribution(int actor,
 		int difference);
+	virtual double egoEndowmentStatistic(int ego, const int * difference,
+		double * currentValues);
 	virtual double egoStatistic(int ego, double * currentValues);
 
 private:
