@@ -29,12 +29,11 @@ class MixedOutStarFunction:
 public MixedNetworkAlterFunction, IntAlterFunction
 {
 public:
-	MixedOutStarFunction(string firstNetworkName, string secondNetworkName);
+	MixedOutStarFunction(std::string firstNetworkName,
+			std::string secondNetworkName);
 
 	virtual void initialize(const Data * pData,
-		State * pState,
-		int period,
-		Cache * pCache);
+		State * pState, int period, Cache * pCache);
 
 	virtual double value(int alter);
 	virtual int intValue(int alter);
