@@ -17,8 +17,7 @@
 #include "network/IncidentTieIterator.h"
 #include "network/CommonNeighborIterator.h"
 
-namespace siena
-{
+namespace siena {
 
 // ----------------------------------------------------------------------------
 // Section: Construction and destruction
@@ -31,27 +30,23 @@ namespace siena
  * are permitted
  */
 OneModeNetwork::OneModeNetwork(int n, bool loopsPermitted) :
-	Network(n, n)
-{
+		Network(n, n) {
 	this->lloopsPermitted = loopsPermitted;
 
 	// Initialize the reciprocal degree counters
 
 	this->lpReciprocalDegree = new int[n];
 
-	for (int i = 0; i < n; i++)
-	{
+	for (int i = 0; i < n; i++) {
 		this->lpReciprocalDegree[i] = 0;
 	}
 }
 
-
 /**
  * Constructs a copy of the given one-mode network.
  */
 OneModeNetwork::OneModeNetwork(const OneModeNetwork & rNetwork) :
-	Network(rNetwork)
-{
+		Network(rNetwork) {
 	// Copy the fields
 	this->lloopsPermitted = rNetwork.lloopsPermitted;
 
@@ -59,20 +54,16 @@ OneModeNetwork::OneModeNetwork(const OneModeNetwork & rNetwork) :
 
 	this->lpReciprocalDegree = new int[rNetwork.n()];
 
-	for (int i = 0; i < rNetwork.n(); i++)
-	{
+	for (int i = 0; i < rNetwork.n(); i++) {
 		this->lpReciprocalDegree[i] = rNetwork.lpReciprocalDegree[i];
 	}
 }
 
-
 /**
  * Assigns the contents of the given network to this network.
  */
-OneModeNetwork & OneModeNetwork::operator=(const OneModeNetwork & rNetwork)
-{
-	if (this != &rNetwork)
-	{
+OneModeNetwork & OneModeNetwork::operator=(const OneModeNetwork & rNetwork) {
+	if (this != &rNetwork) {
 		// Let the base class do its part
 		(Network &) *this = rNetwork;
 
@@ -86,8 +77,7 @@ OneModeNetwork & OneModeNetwork::operator=(const OneModeNetwork & rNetwork)
 
 		// Copy the reciprocal degree counters
 
-		for (int i = 0; i < rNetwork.n(); i++)
-		{
+		for (int i = 0; i < rNetwork.n(); i++) {
 			this->lpReciprocalDegree[i] = rNetwork.lpReciprocalDegree[i];
 		}
 	}
@@ -95,23 +85,18 @@ OneModeNetwork & OneModeNetwork::operator=(const OneModeNetwork & rNetwork)
 	return *this;
 }
 
-
-Network * OneModeNetwork::clone() const
-{
+Network * OneModeNetwork::clone() const {
 	return new OneModeNetwork(*this);
 }
 
-
 /**
  * Deallocates this network.
  */
-OneModeNetwork::~OneModeNetwork()
-{
+OneModeNetwork::~OneModeNetwork() {
 	delete[] this->lpReciprocalDegree;
 	this->lpReciprocalDegree = 0;
 }
 
-
 // ----------------------------------------------------------------------------
 // Section: Accessors
 // ----------------------------------------------------------------------------
@@ -119,12 +104,10 @@ OneModeNetwork::~OneModeNetwork()
 /**
  * Indicates if loops are permitted.
  */
-bool OneModeNetwork::loopsPermitted() const
-{
+bool OneModeNetwork::loopsPermitted() const {
 	return this->lloopsPermitted;
 }
 
-
 // ----------------------------------------------------------------------------
 // Section: Basic structural operations
 // ----------------------------------------------------------------------------
@@ -134,82 +117,65 @@ bool OneModeNetwork::loopsPermitted() const
  * according to the specified type of change. The new value is returned as
  * the result.
  */
-int OneModeNetwork::changeTieValue(int i, int j, int v, ChangeType type)
-{
-	if (i == j && !this->lloopsPermitted)
-	{
-		throw std::invalid_argument(
-			"Loops are not permitted for this network");
+int OneModeNetwork::changeTieValue(int i, int j, int v, ChangeType type) {
+	if (i == j && !this->lloopsPermitted) {
+		throw std::invalid_argument("Loops are not permitted for this network");
 	}
 
 	return Network::changeTieValue(i, j, v, type);
 }
 
-
 /**
  * Updates the state of this network to reflect the withdrawal of a tie
  * from actor <i>i</i> to actor <i>j</i>.
  */
-void OneModeNetwork::onTieWithdrawal(int i, int j)
-{
+void OneModeNetwork::onTieWithdrawal(int i, int j) {
 	// Call the base method first
 	Network::onTieWithdrawal(i, j);
 
 	// A reciprocal tie might be lost.
 
-	if (i == j)
-	{
+	if (i == j) {
 		// Careful with loops!
 		this->lpReciprocalDegree[i]--;
-	}
-	else if (this->tieValue(j, i))
-	{
+	} else if (this->tieValue(j, i)) {
 		this->lpReciprocalDegree[i]--;
 		this->lpReciprocalDegree[j]--;
 	}
 }
 
-
 /**
  * Updates the state of this network to reflect the introduction of a tie
  * from actor <i>i</i> to actor <i>j</i>.
  */
-void OneModeNetwork::onTieIntroduction(int i, int j)
-{
+void OneModeNetwork::onTieIntroduction(int i, int j) {
 	Network::onTieIntroduction(i, j);
 
 	// The tie might be reciprocated.
 
-	if (i == j)
-	{
+	if (i == j) {
 		// Careful with loops!
 		this->lpReciprocalDegree[i]++;
-	}
-	else if (this->tieValue(j, i))
-	{
+	} else if (this->tieValue(j, i)) {
 		this->lpReciprocalDegree[i]++;
 		this->lpReciprocalDegree[j]++;
 	}
 }
 
-
 /**
  * This method removes all ties from this network.
  */
-void OneModeNetwork::clear()
-{
+void OneModeNetwork::clear() {
 	// Let the base class do its part
 	Network::clear();
 
 	// Reset the degree counters.
 
-	for (int i = 0; i < this->n(); i++)
-	{
+	for (int i = 0; i < this->n(); i++) {
 		this->lpReciprocalDegree[i] = 0;
 	}
 }
 
-
 // ----------------------------------------------------------------------------
 // Section: Iterators
 // ----------------------------------------------------------------------------
@@ -217,26 +183,22 @@ void OneModeNetwork::clear()
 /**
  * Returns an iterator over reciprocated ties of the actor <i>i</i>.
  */
-CommonNeighborIterator OneModeNetwork::reciprocatedTies(int i) const
-{
+CommonNeighborIterator OneModeNetwork::reciprocatedTies(int i) const {
 	this->checkSenderRange(i);
 	return CommonNeighborIterator(this->inTies(i), this->outTies(i));
 }
 
-
 /**
  * Returns an iterator over reciprocated ties of the actor <i>i</i> with
  * the alter not less than the given bound.
  */
 CommonNeighborIterator OneModeNetwork::reciprocatedTies(int i,
-	int lowerBound) const
-{
+		int lowerBound) const {
 	this->checkSenderRange(i);
 	return CommonNeighborIterator(this->inTies(i, lowerBound),
-		this->outTies(i, lowerBound));
+			this->outTies(i, lowerBound));
 }
 
-
 // ----------------------------------------------------------------------------
 // Section: Degrees
 // ----------------------------------------------------------------------------
@@ -244,13 +206,11 @@ CommonNeighborIterator OneModeNetwork::reciprocatedTies(int i,
 /**
  * Returns the number of reciprocated ties of the actor <i>i</i>.
  */
-int OneModeNetwork::reciprocalDegree(int i) const
-{
+int OneModeNetwork::reciprocalDegree(int i) const {
 	this->checkSenderRange(i);
 	return this->lpReciprocalDegree[i];
 }
 
-
 // ----------------------------------------------------------------------------
 // Section: Some useful statistics and properties
 // ----------------------------------------------------------------------------
@@ -258,8 +218,7 @@ int OneModeNetwork::reciprocalDegree(int i) const
 /**
  * Indicates if all ties are reciprocated with the same value.
  */
-bool OneModeNetwork::symmetric() const
-{
+bool OneModeNetwork::symmetric() const {
 	// The current implementation is linear in the total number of ties.
 	// The time complexity can be reduced to a constant by maintaining
 	// the number of non-symmetric ties.
@@ -269,21 +228,17 @@ bool OneModeNetwork::symmetric() const
 
 	// Test the incoming and outgoing ties of each actor in turn.
 
-	for (int i = 0; i < this->n() && rc; i++)
-	{
-		if (this->outDegree(i) == this->inDegree(i))
-		{
+	for (int i = 0; i < this->n() && rc; i++) {
+		if (this->outDegree(i) == this->inDegree(i)) {
 			IncidentTieIterator outIter = this->outTies(i);
 			IncidentTieIterator inIter = this->inTies(i);
 
 			// No need to test both iterators for validity, as the numbers
 			// of incoming and outgoing ties are the same.
 
-			while (outIter.valid() && rc)
-			{
-				if (outIter.actor() != inIter.actor() ||
-					outIter.value() != inIter.value())
-				{
+			while (outIter.valid() && rc) {
+				if (outIter.actor() != inIter.actor()
+						|| outIter.value() != inIter.value()) {
 					// Found a mismatch.
 					rc = false;
 				}
@@ -291,9 +246,7 @@ bool OneModeNetwork::symmetric() const
 				outIter.next();
 				inIter.next();
 			}
-		}
-		else
-		{
+		} else {
 			// The numbers of incoming and outgoing ties differ, which
 			// destroys the symmetry immediately.
 
@@ -304,22 +257,18 @@ bool OneModeNetwork::symmetric() const
 	return rc;
 }
 
-
 /**
  * Returns the number of two-paths from <i>i</i> to <i>j</i>.
  */
-int OneModeNetwork::twoPathCount(int i, int j) const
-{
+int OneModeNetwork::twoPathCount(int i, int j) const {
 	return this->truncatedTwoPathCount(i, j, std::numeric_limits<int>::max());
 }
 
-
 /**
  * Returns the number of two-paths from <i>i</i> to <i>j</i> truncated at the
  * given threshold value.
  */
-int OneModeNetwork::truncatedTwoPathCount(int i, int j, int threshold) const
-{
+int OneModeNetwork::truncatedTwoPathCount(int i, int j, int threshold) const {
 	this->checkSenderRange(i);
 	this->checkReceiverRange(j);
 
@@ -331,18 +280,12 @@ int OneModeNetwork::truncatedTwoPathCount(int i, int j, int threshold) const
 	IncidentTieIterator inIter = this->inTies(j);
 	int count = 0;
 
-	while (outIter.valid() && inIter.valid() && count < threshold)
-	{
-		if (outIter.actor() < inIter.actor())
-		{
+	while (outIter.valid() && inIter.valid() && count < threshold) {
+		if (outIter.actor() < inIter.actor()) {
 			outIter.next();
-		}
-		else if (outIter.actor() > inIter.actor())
-		{
+		} else if (outIter.actor() > inIter.actor()) {
 			inIter.next();
-		}
-		else
-		{
+		} else {
 			count++;
 			outIter.next();
 			inIter.next();
@@ -352,14 +295,12 @@ int OneModeNetwork::truncatedTwoPathCount(int i, int j, int threshold) const
 	return count;
 }
 
-
 /**
  * This method indicated that there are no two-paths from <i>i</i> to <i>j</i>
  * via an intermediate actor below the given bound.
  */
-bool OneModeNetwork::noTwoPaths(int i, int j, int intermediateActorUpperBound)
-	const
-{
+bool OneModeNetwork::noTwoPaths(int i, int j,
+		int intermediateActorUpperBound) const {
 	this->checkSenderRange(i);
 	this->checkReceiverRange(j);
 
@@ -372,22 +313,14 @@ bool OneModeNetwork::noTwoPaths(int i, int j, int intermediateActorUpperBound)
 	IncidentTieIterator inIter = this->inTies(j);
 	bool found = false;
 
-	while (outIter.valid() &&
-		inIter.valid() &&
-		!found &&
-		outIter.actor() < intermediateActorUpperBound &&
-		inIter.actor() < intermediateActorUpperBound)
-	{
-		if (outIter.actor() < inIter.actor())
-		{
+	while (outIter.valid() && inIter.valid() && !found
+			&& outIter.actor() < intermediateActorUpperBound
+			&& inIter.actor() < intermediateActorUpperBound) {
+		if (outIter.actor() < inIter.actor()) {
 			outIter.next();
-		}
-		else if (outIter.actor() > inIter.actor())
-		{
+		} else if (outIter.actor() > inIter.actor()) {
 			inIter.next();
-		}
-		else
-		{
+		} else {
 			found = true;
 		}
 	}
@@ -395,26 +328,22 @@ bool OneModeNetwork::noTwoPaths(int i, int j, int intermediateActorUpperBound)
 	return !found;
 }
 
-
 /**
  * This method indicated that there is at least one two-path from <i>i</i>
  * to <i>j</i>.
  */
-bool OneModeNetwork::existsTwoPath(int i, int j) const
-{
+bool OneModeNetwork::existsTwoPath(int i, int j) const {
 	return !this->noTwoPaths(i, j, std::numeric_limits<int>::max());
 }
 
-
 /**
  * This method tests if there are at most <i>k</i> two-paths from <i>i</i>
  * to <i>j</i>.
  * If the test is positive, the number of such paths is stored
  * in the variable <i>twoPathCount</i>.
  */
-bool OneModeNetwork::atMostKTwoPaths(int i, int j, int k, int & twoPathCount)
-	const
-{
+bool OneModeNetwork::atMostKTwoPaths(int i, int j, int k,
+		int & twoPathCount) const {
 	this->checkSenderRange(i);
 	this->checkReceiverRange(j);
 
@@ -426,18 +355,12 @@ bool OneModeNetwork::atMostKTwoPaths(int i, int j, int k, int & twoPathCount)
 	IncidentTieIterator inIter = this->inTies(j);
 	twoPathCount = 0;
 
-	while (outIter.valid() && inIter.valid() && twoPathCount <= k)
-	{
-		if (outIter.actor() < inIter.actor())
-		{
+	while (outIter.valid() && inIter.valid() && twoPathCount <= k) {
+		if (outIter.actor() < inIter.actor()) {
 			outIter.next();
-		}
-		else if (outIter.actor() > inIter.actor())
-		{
+		} else if (outIter.actor() > inIter.actor()) {
 			inIter.next();
-		}
-		else
-		{
+		} else {
 			twoPathCount++;
 			outIter.next();
 			inIter.next();
@@ -447,36 +370,27 @@ bool OneModeNetwork::atMostKTwoPaths(int i, int j, int k, int & twoPathCount)
 	return twoPathCount <= k;
 }
 
-
 /**
  * This method counts the number of actors participating in three or all four
  * ties with actors <i>i</i> and <i>j</i>. These numbers are stored in
  * <i>n3</i> and <i>n4</i>, respectively.
  */
-void OneModeNetwork::neighborCensus(int i, int j, int & n3, int & n4) const
-{
+void OneModeNetwork::neighborCensus(int i, int j, int & n3, int & n4) const {
 	this->checkSenderRange(i);
 	this->checkSenderRange(j);
 
 	// There are four relevant iterators for actors i and j -- two for
 	// incoming ties and two for outgoing ties.
 
-	IncidentTieIterator iterators[] =
-	{
-			this->inTies(i),
-			this->outTies(i),
-			this->inTies(j),
-			this->outTies(j)
-	};
+	IncidentTieIterator iterators[] = { this->inTies(i), this->outTies(i),
+			this->inTies(j), this->outTies(j) };
 
 	// How many of these iterators are valid?
 
 	int validIteratorCount = 0;
 
-	for (int i = 0; i < 4; i++)
-	{
-		if (iterators[i].valid())
-		{
+	for (int i = 0; i < 4; i++) {
+		if (iterators[i].valid()) {
 			validIteratorCount++;
 		}
 	}
@@ -489,16 +403,13 @@ void OneModeNetwork::neighborCensus(int i, int j, int & n3, int & n4) const
 	// While there are at least three valid iterators, there is a chance
 	// to encounter an actor involved in at least three ties with i and j.
 
-	while (validIteratorCount >= 3)
-	{
+	while (validIteratorCount >= 3) {
 		// Find the minimum of the current actors of the valid iterators.
 
 		int minActor = std::numeric_limits<int>::max();
 
-		for (int i = 0; i < 4; i++)
-		{
-			if (iterators[i].valid())
-			{
+		for (int i = 0; i < 4; i++) {
+			if (iterators[i].valid()) {
 				minActor = std::min(minActor, iterators[i].actor());
 			}
 		}
@@ -506,10 +417,8 @@ void OneModeNetwork::neighborCensus(int i, int j, int & n3, int & n4) const
 		// How many iterators have this minimum as the current actor?
 		int count = 0;
 
-		for (int i = 0; i < 4; i++)
-		{
-			if (iterators[i].valid() && iterators[i].actor() == minActor)
-			{
+		for (int i = 0; i < 4; i++) {
+			if (iterators[i].valid() && iterators[i].actor() == minActor) {
 				count++;
 
 				// Advance the iterator right away and
@@ -517,8 +426,7 @@ void OneModeNetwork::neighborCensus(int i, int j, int & n3, int & n4) const
 
 				iterators[i].next();
 
-				if (!iterators[i].valid())
-				{
+				if (!iterators[i].valid()) {
 					validIteratorCount--;
 				}
 			}
@@ -526,27 +434,28 @@ void OneModeNetwork::neighborCensus(int i, int j, int & n3, int & n4) const
 
 		// Update the counters.
 
-		if (count == 3)
-		{
+		if (count == 3) {
 			n3++;
-		}
-		else if (count == 4)
-		{
+		} else if (count == 4) {
 			n4++;
 		}
 	}
 }
 
+/**
+ * @copydoc Network::isOneMode()
+ */
+bool OneModeNetwork::isOneMode() const {
+	return true;
+}
 
 /**
  * Returns the maximal possible number of ties in this network.
  */
-int OneModeNetwork::maxTieCount() const
-{
+int OneModeNetwork::maxTieCount() const {
 	int count = this->n() * this->n();
 
-	if (!this->lloopsPermitted)
-	{
+	if (!this->lloopsPermitted) {
 		count = this->n() * (this->n() - 1);
 	}
 
